.. pypel documentation master file, created by
   sphinx-quickstart on Thu Oct 25 03:25:39 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pypel
=====

``pypel`` is a simple tool to manage receipts. It uses `XMP`_ to store metatada
inside receipts so you can share them in a very easy way.

.. _XMP: http://en.wikipedia.org/wiki/Extensible_Metadata_Platform


.. toctree::
   :maxdepth: 2

   installing_pypel
   command_line
   changelog
   licensing

:Release: |version|
:Date: September 12, 2013
